Bankr - Changelog
=================

v0.0.3 (02/2025)
----------------

- Corrections of i18n
- "source" in bankr-v1.yaml switched to string to simplify the edit of transactions
- Improvement of the Dashboards, but still preliminary
- Some TODOs removed, others are left
- Fragments of command "app" added


v0.0.2 (01/2025)
----------------

- Improved documentation (p0.0.2)
- Sample data added


v0.0.1 (01/2025)
----------------

Initial release
